==========================
Frequently Asked Questions
==========================

What is the relationship to ``scipy.ndimage``?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Currently, ``mahotas`` still depends on ``scipy.ndimage`` for some of its
operations. Over the long term, I'd like to remove that dependency.

